@@ -66,11 +66,24 @@ NG_NUM cached_ng = -1;
 time_t cached_time = 0;
 ART_NUM cached_cnt = 0;
 ART_NUM cached_absfirst = 0;
+/* We keep track of whether the cache of the group was made with ThreadedGroup
+ * set, because if it wasn't then there is no threading information.
+ * If we don't flush the cache on a change of ThreadedGroup, then trn tries
+ * to access the threading information when it's invalid, causing errors
+ * and occasionally segfaults. Possibly we could avoid having to completely
+ * flushing the cache in this situation, but I don't think it will occur
+ * very often, and this fix should definitely work, whereas a more complex
+ * solution has more chance of being buggy [esp. since I don't actually
+ * know the trn code that well :->]
+ *   -- Peter Maydell <pmaydell@chiark.greenend.org.uk>, 8/9/1999
+ */
+bool cached_threaded = 0;
 
 void
 build_cache()
 {
     if (cached_ng == ng && cached_absfirst == absfirst
+     && cached_threaded == ThreadedGroup
      && time((time_t*)NULL) < cached_time + 6*60*60L) {
 	grow_cache(lastart);
 	rc_to_bits();
@@ -85,6 +98,7 @@ build_cache()
     close_cache();
 
     cached_ng = ng;
+    cached_threaded = ThreadedGroup;
     cached_absfirst = absfirst;
     cached_time = time((time_t*)NULL);
     cached_cnt = lastart-absfirst+2 + 10;
