@@ -88,7 +88,7 @@ struct headtype htype[HEAD_LAST] = {
     {"acategory",	0,	0,	9,	HT_HIDE		},
     {"anpa",		0,	0,	4,	HT_HIDE		},
     {"codes",		0,	0,	5,	HT_HIDE		},
-#ifdef MIME_SUPPORT
+#if defined(MIMESHOW) || defined(MIMESTORE)
     {"content-type",	0,	0,	12,	HT_MAGIC	},
     {"content-transfer-encoding",
 			0,	0,	25,	HT_MAGIC	},
