@@ -868,8 +868,23 @@ char *stoppers;
 		    if (in_ng) {
 			parseheader(art);
 			if (htype[REFS_LINE].ht_minpos >= 0) {
+			    int trial_size=sizeof(scrbuf);
+                            char * trial_buf=0;
+
 			    refs_buf = fetchlines(art,REFS_LINE);
-			    refscpy(scrbuf,(sizeof scrbuf),refs_buf);
+			    do {
+			      if (trial_buf != 0) trial_size = trial_size*2;
+			      free(trial_buf);
+			      trial_buf = malloc(trial_size);
+			    } while (refscpy(trial_buf,trial_size,refs_buf) < 1);
+			    if (strlen(trial_buf)+1 < (sizeof scrbuf)) {
+			      strcpy(scrbuf, trial_buf);
+			    }
+			    else {
+			      reducerefs(scrbuf,(sizeof scrbuf),trial_buf);
+			    }
+
+			    free(trial_buf);			
 			}
 			else
 			    *scrbuf = '\0';
@@ -885,21 +900,18 @@ char *stoppers;
 		    }
 		    parseheader(art);
 		    if (htype[REFS_LINE].ht_minpos >= 0) {
+  		        int trial_size=sizeof(scrbuf);
+		        char * trial_buf=0;
+
 			refs_buf = fetchlines(art,REFS_LINE);
-			refscpy(scrbuf,(sizeof scrbuf),refs_buf);
-			/* no more than 3 prior references PLUS the
-			** root article allowed, including the one
-			** concatenated below */
-			if ((s = rindex(scrbuf,'<')) > scrbuf) {
-			    *s = '\0';
-			    h = rindex(scrbuf,'<');
-			    *s = '<';
-			    if (h > scrbuf) {
-				s = index(scrbuf+1,'<');
-				if (s < h)
-				    strcpy(s,h);
-			    }
-			}
+
+			do {
+			  if (trial_buf != 0) trial_size = trial_size*2;
+			  free(trial_buf);
+			  trial_buf = malloc(trial_size);
+			} while (refscpy(trial_buf,trial_size,refs_buf) < 1);
+			reducerefs(scrbuf,(sizeof scrbuf),trial_buf);
+			free(trial_buf);
 		    }
 		    else
 			*scrbuf = '\0';
@@ -1247,7 +1259,7 @@ char *pattern;
 
 /* copy a references line, normalizing as we go */
 
-void
+int
 refscpy(dest,destsize,src)
 register char *dest, *src;
 register int destsize;
@@ -1300,8 +1312,49 @@ register int destsize;
 	    *dest++ = ' ';
     }
     *dest = '\0';
+    return(destsize);
 } 
 
+/* reduce a references line */
+/* note, modifies src */
+void
+reducerefs(dest,destsize,src)
+register char *dest, *src;
+register int destsize;
+{
+  char * s;
+  char * h;
+  /* no more than 3 prior references PLUS the
+  ** root article allowed, including the one
+  ** concatenated below */
+  if ((s = rindex(src,'<')) > src) {
+    *s = '\0';
+    h = rindex(src,'<');
+    *s = '<';
+    if (h > src) {
+      s = index(src+1,'<');
+      if (s < h)
+	strcpy(s,h);
+    }
+  }
+  if (strlen(src) < destsize) {
+    strcpy(dest,src);
+  }
+  else {
+    if ((s = rindex(src,'<')) > src) {
+      if (strlen(s) < destsize) {
+	strcpy(dest,s);
+      }
+      else {
+	*dest = '\0';
+      }
+    }
+    else {
+      *dest = '\0';
+    }
+  }
+}
+
 /* get the person's real name from /etc/passwd */
 /* (string is overwritten, so it must be copied) */
 
