@@ -339,6 +339,7 @@ rewrite_kfile(thru)
 ART_NUM thru;
 {
     bool no_kills = 0, has_star_commands = FALSE;
+    char *oldkf, *newkf;
 
     if (localkfp) {
 	fseek(localkfp,0L,0);		/* rewind current file */
@@ -352,12 +353,16 @@ ART_NUM thru;
 	    no_kills = 1;
     }
     strcpy(buf,filexp(getval("KILLLOCAL",killlocal)));
+    oldkf = savestr(buf);
+    strcat(buf, ".tmp");
+    newkf = savestr(buf);
     if (!localkfp)
-	makedir(buf,MD_FILE);
-    UNLINK(buf);			/* to prevent file reuse */
-    if (no_kills)
+	makedir(newkf,MD_FILE);
+    if (no_kills) {
+        UNLINK(buf);
 	open_kfile(KF_LOCAL);		/* close file and reset open flag */
-    else if (newkfp = fopen(buf,"w")) {
+    }
+    else if (newkfp = fopen(newkf,"w")) {
 	fprintf(newkfp,"THRU %ld\n",(long)thru);
 	while (localkfp && fgets(buf,LBUFLEN,localkfp) != Nullch) {
 	    if (strnEQ(buf,"THRU",4))
@@ -381,12 +386,21 @@ ART_NUM thru;
 	/* Append all the still-valid thread commands */
 	hashwalk(msgid_hash, write_thread_commands, 0);
 	fclose(newkfp);
+#ifdef HAS_RENAME
+	rename(newkf, oldkf);
+#else
+	UNLINK(oldkf);
+	safelink(newkf, oldkf);
+        UNLINK(newkf);
+#endif
 	open_kfile(KF_LOCAL);		/* and reopen local file */
     }
     else
-	printf(cantcreate,buf) FLUSH;
+	printf(cantcreate,newkf) FLUSH;
     localkf_changes = 0;
     has_normal_kills = FALSE;
+    free(newkf);
+    free(oldkf);
 }
 
 /* edit KILL file for newsgroup */
