@@ -282,7 +282,8 @@ char *what;
 int flags;
 {
     char *ntoforget;
-    char promptbuf[128];
+#define PBLEN 240
+    char promptbuf[PBLEN+1];
     int autosub;
 
 #ifdef VERBOSE
@@ -347,11 +348,11 @@ int flags;
 	} else {
 #ifdef VERBOSE
 	IF(verbose)
-	    sprintf(promptbuf,"\nNewsgroup %s not in .newsrc -- subscribe?",ngname);
+            snprintf(promptbuf,PBLEN,"\nNewsgroup %s not in .newsrc -- subscribe?",ngname);
 	ELSE
 #endif
 #ifdef TERSE
-	    sprintf(promptbuf,"\nSubscribe %s?",ngname);
+            snprintf(promptbuf,PBLEN,"\nSubscribe %s?",ngname);
 #endif
 reask_add:
 	in_char(promptbuf,'A',"ynYN");
@@ -418,13 +419,13 @@ Type N to leave all remaining new groups unsubscribed.\n", ngname)
     else if (rcchar[ng] == NEGCHAR) {	/* unsubscribed? */
 #ifdef VERBOSE
 	IF(verbose)
-	    sprintf(promptbuf,
+            snprintf(promptbuf, PBLEN,
 "\nNewsgroup %s is unsubscribed -- resubscribe?",ngname)
   FLUSH;
 	ELSE
 #endif
 #ifdef TERSE
-	    sprintf(promptbuf,"\nResubscribe %s?",ngname)
+            snprintf(promptbuf,PBLEN,"\nResubscribe %s?",ngname)
 	      FLUSH;
 #endif
 reask_unsub:
